#include <iostream>
#include <fstream>
#include "Challenges.pb.h"
using namespace std;

/* This file shows how to parse and read .secret files.
 * Given the path to a .secret file, it prints the contents of the parsed
 * message. It also demonstrates how to access fields in the parsed message.
 *
 * You will need to install the Google protocol buffer library for C++ to
 * build and run this code.
 *
 * More information about parsing can be found at
 * https://developers.google.com/protocol-buffers/docs/reference/cpp-generated
 */

int main(int argc, char* argv[]) {
  // Verify that the version of the library that we linked against is
  // compatible with the version of the headers we compiled against.
  GOOGLE_PROTOBUF_VERIFY_VERSION;

  if (argc != 2) {
    cerr << "Usage:  " << argv[0] << " path/to/.secret" << endl;
    return -1;
  }

  Secret secret;
  // Read the secret.
  fstream input(argv[1], ios::in | ios::binary);
  if (!secret.ParseFromIstream(&input)) {
    cerr << "Failed to parse secret." << endl;
    return -1;
  }

  //print the entire secret
  cout << secret.google::protobuf::Message::DebugString() << endl;

  // access a member of the Secret message
  // first decoding basis coefficient of the secret
  cout << secret.s().xs(0) << endl;

  cout << "See source code in SecretParser.cc for examples of how to access specific message members." << endl;

  // Optional:  Delete all global objects allocated by libprotobuf.
  google::protobuf::ShutdownProtobufLibrary();

  return 0;
}
